@@ -879,16 +879,16 @@ Returns:
 
     $List = (
         {
-            ID          => 123,
+            ID            => 123,
             InternalField => 0,
-            Name        => 'nameforfield',
-            Label       => 'The label to show',
-            FieldType   => 'Text',
-            ObjectType  => 'Article',
-            Config      => $ConfigHashRef,
-            ValidID     => 1,
-            CreateTime  => '2011-02-08 15:08:00',
-            ChangeTime  => '2011-06-11 17:22:00',
+            Name          => 'nameforfield',
+            Label         => 'The label to show',
+            FieldType     => 'Text',
+            ObjectType    => 'Article',
+            Config        => $ConfigHashRef,
+            ValidID       => 1,
+            CreateTime    => '2011-02-08 15:08:00',
+            ChangeTime    => '2011-06-11 17:22:00',
         },
         {
             ID            => 321,
@@ -902,7 +902,7 @@ Returns:
             CreateTime    => '2010-09-11 10:08:00',
             ChangeTime    => '2011-01-01 01:01:01',
         },
-        ...
+        # ...
     );
 
 =cut
@@ -1129,8 +1129,8 @@ checks for duplicate order numbers and gaps in the numbering.
 
 Returns:
 
-    $Success = 1;                       # or 0 in case duplicates or gaps in the dynamic fields
-                                        #    order numbering
+    $Success = 1;   # or 0 in case duplicates or gaps in the dynamic fields
+                    # order numbering
 
 =cut
 
@@ -1178,11 +1178,11 @@ NOTE: Only use object mappings for dynamic fields that must support non-integer
 like customer user logins and customer company IDs.
 
     my $ObjectMapping = $DynamicFieldObject->ObjectMappingGet(
-        ObjectName            => $ObjectName,    # Name or array ref of names of the object(s) to get the ID(s) for
+        ObjectName => $ObjectName,    # Name or array ref of names of the object(s) to get the ID(s) for
                                                  # Note: either give ObjectName or ObjectID
-        ObjectID              => $ObjectID,      # ID or array ref of IDs of the object(s) to get the name(s) for
+        ObjectID   => $ObjectID,      # ID or array ref of IDs of the object(s) to get the name(s) for
                                                  # Note: either give ObjectName or ObjectID
-        ObjectType            => 'CustomerUser', # Type of object to get mapping for
+        ObjectType => 'CustomerUser', # Type of object to get mapping for
     );
 
     Returns for parameter ObjectID:
@@ -1323,7 +1323,7 @@ sub ObjectMappingGet {
 
 =head2 ObjectMappingCreate()
 
-Creates an object mapping for the given given object name.
+Creates an object mapping for the given object name.
 
 NOTE: Only use object mappings for dynamic fields that must support non-integer object IDs,
 like customer user logins and customer company IDs.
@@ -1694,16 +1694,32 @@ sub _DynamicFieldReorder {
 
 =head2 _SanitizeConfig()
 
-Currently only removes JavaScript code from configured regular expression error messages.
+This function cleans up the config:
 
-    $DynamicFieldObject->_SanitizeConfig(
+Removes JavaScript code from configured regular expression error messages:
+
+    my $Success = $DynamicFieldObject->_SanitizeConfig(
 
         # 'Config' part of a dynamic field config hash returned by DynamicFieldGet()
         # or given to DynamicFieldAdd() and -Update()
         Config => $Config,
     );
 
-    Returns 1.
+
+Removes reserved keywords in link configuration:
+
+    my $Success = $DynamicFieldObject->_SanitizeConfig(
+        Config => {
+            Link => 'https://www.znuny.org/[% Data.Link %]/[% Data.LinkPreview %]/[% Data.Title %]/[% Data.Value %]'
+        },
+    );
+
+    $Config->{Link} = 'https://www.znuny.org////';
+
+
+Return:
+
+    my $Success = 1;
 
 =cut
 
@@ -1724,13 +1740,7 @@ sub _SanitizeConfig {
         return;
     }
 
-    if ( !IsHashRefWithData( $Param{Config} ) ) {
-        $LogObject->Log(
-            Priority => 'error',
-            Message  => "Parameter 'Config' must be a hash ref with data!",
-        );
-        return;
-    }
+    return if !IsHashRefWithData( $Param{Config} );
 
     # Remove JavaScript, etc. from regex error messages.
     # This prevents execution of arbitrary JavaScript when showing
@@ -1756,6 +1766,13 @@ sub _SanitizeConfig {
         $RegExConfig->{ErrorMessage} = $SafeRegExErrorMessage{String} // '';
     }
 
+    my @ReservedKeywords = (qw(Link LinkPreview Title Value));
+    if ( $Param{Config}->{Link} ) {
+        for my $Keyword (@ReservedKeywords) {
+            $Param{Config}->{Link} =~ s{\[\% Data\.$Keyword \%\]}{}g;
+        }
+    }
+
     return 1;
 }
 
