@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -168,8 +168,8 @@ run a generic agent job
 
     $GenericAgentObject->JobRun(
         Job          => 'JobName',
-        OnlyTicketID => 123,     # (optional) for event based Job execution
-        SleepTime    => 100_000  # (optional) sleeptime per ticket in microseconds
+        OnlyTicketID => 123,        # (optional) for event based Job execution
+        SleepTime    => 100_000,    # (optional) sleeptime per ticket in microseconds
         UserID       => 1,
     );
 
@@ -740,7 +740,7 @@ adds a new job to the database
         Name => 'JobName',
         Data => {
             Queue => 'SomeQueue',
-            ...
+            # ...
             Valid => 1,
         },
         UserID => 123,
@@ -908,12 +908,12 @@ sub JobEventList {
 run a generic agent job on a ticket
 
     $GenericAgentObject->_JobRunTicket(
-        TicketID => 123,
+        TicketID     => 123,
         TicketNumber => '2004081400001',
-        Config => {
+        Config       => {
             %Job,
         },
-        UserID => 1,
+        UserID       => 1,
     );
 
 =cut
@@ -979,7 +979,7 @@ sub _JobRunTicket {
         );
 
         if ( IsHashRefWithData( \%Ticket ) ) {
-            my %CustomerUserData = ();
+            my %CustomerUserData;
             if ( IsStringWithData( $Ticket{CustomerUserID} ) ) {
                 %CustomerUserData = $Kernel::OM->Get('Kernel::System::CustomerUser')->CustomerUserDataGet(
                     User => $Ticket{CustomerUserID},
