@@ -1,5 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -343,7 +344,7 @@ sub LinkAdd {
     # check if source and target are the same object
     if ( $Param{SourceObject} eq $Param{TargetObject} && $Param{SourceKey} eq $Param{TargetKey} ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
+            Priority => 'notice',
             Message  => 'Impossible to link object with itself!',
         );
         return;
@@ -436,7 +437,7 @@ sub LinkAdd {
         if ( $Existing{StateID} ne $StateID ) {
 
             $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
+                Priority => 'notice',
                 Message  => "Link already exists between these two objects "
                     . "with a different state id '$Existing{StateID}'!",
             );
@@ -454,7 +455,7 @@ sub LinkAdd {
 
         # log error
         $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
+            Priority => 'notice',
             Message  => 'Link already exists between these two objects in opposite direction!',
         );
         return;
@@ -494,7 +495,7 @@ sub LinkAdd {
 
             # existing link type is in a type group with the new link
             $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
+                Priority => 'notice',
                 Message  => 'Another Link already exists within the same type group!',
             );
 
@@ -603,8 +604,8 @@ deletes old links from database
 return true
 
     $True = $LinkObject->LinkCleanup(
-        State  => 'Temporary',
-        Age    => ( 60 * 60 * 24 ),
+        State => 'Temporary',
+        Age   => ( 60 * 60 * 24 ),
     );
 
 =cut
@@ -1179,14 +1180,14 @@ Return
     };
 
     my $LinkList = $LinkObject->LinkListWithData(
-        Object                          => 'Ticket',
-        Key                             => '321',
-        Object2                         => 'FAQ',         # (optional)
-        State                           => 'Valid',
-        Type                            => 'ParentChild', # (optional)
-        Direction                       => 'Target',      # (optional) default Both (Source|Target|Both)
-        UserID                          => 1,
-        ObjectParameters                => {              # (optional) backend specific flags
+        Object           => 'Ticket',
+        Key              => '321',
+        Object2          => 'FAQ',         # (optional)
+        State            => 'Valid',
+        Type             => 'ParentChild', # (optional)
+        Direction        => 'Target',      # (optional) default Both (Source|Target|Both)
+        UserID           => 1,
+        ObjectParameters => {              # (optional) backend specific flags
             Ticket => {
                 IgnoreLinkedTicketStateTypes => 0|1,
             },
@@ -2245,9 +2246,9 @@ sub StateList {
 checks read permission for a given object and UserID.
 
     $Permission = $LinkObject->ObjectPermission(
-        Object  => 'Ticket',
-        Key     => 123,
-        UserID  => 1,
+        Object => 'Ticket',
+        Key    => 123,
+        UserID => 1,
     );
 
 =cut
@@ -2288,9 +2289,9 @@ Return
     );
 
     %Description = $LinkObject->ObjectDescriptionGet(
-        Object  => 'Ticket',
-        Key     => 123,
-        UserID  => 1,
+        Object => 'Ticket',
+        Key    => 123,
+        UserID => 1,
     );
 
 =cut
@@ -2342,7 +2343,7 @@ Returns:
 
     $ObjectList = $LinkObject->ObjectSearch(
         Object       => 'ITSMConfigItem',
-        SubObject    => 'Computer'         # (optional)
+        SubObject    => 'Computer',        # (optional)
         SearchParams => $HashRef,          # (optional)
         UserID       => 1,
     );
