@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -16,7 +16,6 @@ our @ObjectDependencies = (
     'Kernel::System::Log',
 );
 
-use Kernel::System::VariableCheck qw(:all);
 use parent qw( Kernel::System::UnitTest::TicketToUnitTest::Base );
 
 sub Run {
@@ -46,7 +45,7 @@ sub Run {
 
 \$Self->True(
     \$Success,
-    'TicketAccountTime "$Param{TimeAccounting}" was successfull.',
+    'TicketAccountTime "$Param{TimeAccounting}" was successful.',
 );
 
 OUTPUT
